# coding: cp1251

if 'const':
  TEXT_LENGTH      = 128;
  MAX_TEXT_LENGTH  = 255;
  etNoAllDocument = -6;  # "Документ не активизирован
  etNoSPCDocument = -5;  # "Документ не активизирован или не является спецификацие
  etLibraryClose  = -4;  # "Принудительное завершение выполнения библиотеки
  etNoPreView     = -3;  # "В режиме Preview нельзя создавать или открывать выдимые документы
  etNoDocument    = -2;  # "Документ не активизирован или не является листом/фрагментом
  etAbort         = -1;  # "Аварийное завершение (?)
  etSuccess       = 0;   # "Успешное завершение
  etError1        = 1;   # "Ошибка! Попытка выполнить EndObj \n\r при неоткрытом составном элементе"
  etError2        = 2;   # "Ошибка! Попытка поставить в сплайн \n\r недопустимый объект"
  etError3        = 3;   # "Ошибка! Попытка поставить в штриховку \n\r недопустимый объект"
  etError4        = 4;   # "Ошибка! Попытка выполнить delete_mtr /n /r при невведенной локальной системе координат"
  etError5        = 5;   # "Ошибка при введении локальной системы координат"
  etError6        = 6;   # "Ошибка ! Группа дожна быть постоянной"
  etError7        = 7;   # "Ошибка ! объект не существует"
  etError8        = 8;   # "Ошибка! В текущем документе объект не найден"
  etError9        = 9;   # "Ошибка! Нет памяти!"
  etError10       = 10;  # "Ошибка! Вырожденный объект"
  etError11       = 11;  # "Ошибка ! Неверный указатель группы
  etError12       = 12;  # "Ошибка ! Объект не пренадлежит группе
  etError13       = 13;  # "Ошибка ! Объект нельзя поставить в группу
  etError14       = 14;  # "Ошибка ! Группа должна быть временной
  etError15       = 15;  # "Первый объект не существует  или не является кривой
  etError16       = 16;  # "Второй объект не существует  или не является кривой
  etError17       = 17;  # "Кривые расположены в разных видах
  etError18       = 18;  # "Не совпадают СК определения кривых (геом и анн)
  etError19       = 19;  # "Первый объект не является кривой
  etError20       = 20;  # "Второй объект не является кривой
  etError21       = 21;  # "Объект уже в группе
  etError22       = 22;  # "Ошибка! Временный объект не может быть \n\r в постоянной группе"
  etError23       = 23;  # "В документе не предусмотрена работа с видами"
  etError24       = 24;  # "Ошибка! Вид с заданным номером уже существует"
  etError25       = 25;  # "Ошибка! Недопустимое значение номера вида"
  etError26       = 26;  # "Ошибка! В текущем документе вид не найден"
  etError27       = 27;  # "Ошибка! Неверный указатель вида
  etError28       = 28;  # "Ошибка! Вид не редактируется
  etError29       = 29;  # "Ошибка! Состояние вида задано неверно"
  etError30       = 30;  # "Ошибка! Параметры текущего вида не меняются"
  etError31       = 31;  # "Ошибка! Неверный указатель макроэлемента"
  etError32       = 32;  # "Ошибка! Должен быть режим редактирования макроэлемента"
  etError33       = 33;  # "Ошибка! Неверный тип параметров редактирования макроэлемента"
  etError34       = 34;  # "Ошибка! В виде остались не закрытые составные элементы"
  etError35       = 35;  # "Ошибка! Неверный указатель слоя"
  etError36       = 36;  # "Ошибка! Недопустимое значение номера слоя"
  etError37       = 37;  # "Ошибка! В текущем виде слой не найден"
  etError38       = 38;  # "Ошибка! У объекта параметров нет"
  etError39       = 39;  # "Ошибка! Не соответствует размер структуры параметров"
  etError40       = 40;  # "Ошибка! Состояние слоя задано неверно'
  etError41       = 41;  # "Ошибка! Параметры текущего слоя не меняются"
  etError42       = 42;  # "Ошибка! В указанном виде редактирование запрещено"
  etError43       = 43;  # "Ошибка! В указанном слое редактирование запрещено"
  etError44       = 44;  # "Ошибка! Параметры системного вида не меняется"
  etError45       = 45;  # "Ошибка! Попытка поставить в текст \n\r недопустимый объект"
  etError46       = 46;  # "Ошибка! Неверный ввод текста"
  etError47       = 47;  # "Ошибка! Неверный тип массива"
  etError48       = 48;  # "Ошибка! Неверный указатель массива
  etError49       = 49;  # "Ошибка! Указатель на структуру параметров должен быть не NULL"
  etError50       = 50;  # "Ошибка! Неверный индекс массива
  etError51       = 51;  # "Ошибка! Неверное редактирование текста
  etError52       = 52;  # "Ошибка! Bezier-точка используется не верно"
  etError53       = 53;  # "Ошибка! Неправильный индекс "
  etError54       = 54;  # "Ошибка! Режим работы документа задан неверно "
  etError55       = 55;  # "Ошибка! Режим обработки документов задан неверно "
  etError56       = 56;  # "Ошибка! Неверный указатель документа"
  etError57       = 57;  # "Ошибка! Попытка сохранить документ без имени"
  etError58       = 58;  # "Ошибка! Документ закрыт без сохранения"
  etError59       = 59;  # "Ошибка! Имя файла документа задано не верно"
  etError60       = 60;  # "Ошибка! Объект не соответствует типу поиска"
  etError61       = 61;  # "Ошибка! Не могу создать документ.\n\r Документ с таким именем уже открыт"
  etError62       = 62;  # "Ошибка! Поиск объектов задан неверно"
  etError63       = 63;  # "Ошибка! В текущем документе итератор не найден"
  etError64       = 64;  # "Ошибка! Документ не найден"
  etError65       = 65;  # "Ошибка! Документ открыт в видимом режиме"
  etError66       = 66;  # "Ошибка! Документ открыт в невидимом режиме"
  etError67       = 67;  # "Ошибка! Нельзя менять тип документа"
  etError68       = 68;  # "Стиль спецификации не найден"
  etError69       = 69;  # "Ошибка! У фрагмента нет размеров  листа"
  etError70       = 70;  # "Режим работы документа не меняется"
  etError71       = 71;  # "Ошибка! Вид должен быть активным или текущим"
  etError72       = 72;  # "Ошибка! Тип атрибута задан неверно"
  etError73       = 73;  # "Ошибка! Тип атрибута не найден"
  etError74       = 74;  # "Ошибка! Неверный пароль"
  etError75       = 75;  # "Ошибка! Тип атрибута не найден"
  etError76       = 76;  # "Ошибка! Атрибут в документе не найден"
  etError77       = 77;  # "Ошибка! Атрибут не принадлежит объекту"
  etError78       = 78;  # "Ошибка! Неправильный номер колонки атрибута"
  etError79       = 79;  # "Ошибка! Неправильный номер строки атрибута"
  etError80       = 80;  # "Ошибка! Родительское окно не найдено"
  etError81       = 81;  # "Ошибка! Библиотека атрибутов не найдена или ошибка в библиотеке"
  etError82       = 82;  # "Ошибка! Текст размера задан неверно"
  etError83       = 83;  # "Ошибка! Параметры привязки размера заданы неверно"
  etError84       = 84;  # "Ошибка! Текст шероховатости задан неверно"
  etError85       = 85;  # "Ошибка! Неверный указатель линейного размера"
  etError86       = 86;  # "Ошибка! Текст линии выноски задан неверно""
  etError87       = 87;  # "Ошибка! Параметры линии выноски заданы неверно""
  etError88       = 88;  # "Ошибка! Попытка поставить в контур \n\r недопустимый объект"
  etError89       = 89;  # "Ошибка! У звеньев контура не совпадают  узлы"
  etError90       = 90;  # "В документе не предусмотрена работа с техническими требованиями"
  etError91       = 91;  # "В документе не предусмотрена работа с неуказанной шероховатостью"
  etError92       = 92;  # "Ошибка! Попытка поставить в тавлицу \n\r недопустимый объект"
  etError93       = 93;  # "Ошибка! В составном объекте не предусмотрена  работа с техническими требованиями"
  etError94       = 94;  # "В документе не предусмотрена работа с основной надписью"
  etError95       = 95;  # "Ошибка! В составном объекте не предусмотрена  работа с основной надписью"
  etError96       = 96;  # "Ошибка! Попытка поставить в допуск формы \n\r недопустимый объект"
  etError97       = 97;  # "Ошибка! Nurbs-точка используется не верно"
  etError98       = 98;  # "Ошибка! Попытка поставить в полилинию недопустимый объект"
  etError99       = 99;  # "Ошибка! Объект должен быть геометрическим"
  etError100      = 100; # "Ошибка! Эквидистанту в контур включать нельзя"
  etError101      = 101; # "Ошибка! Неправильная работа с указателем на определение вставного фрагмента"
  etError102      = 102; # "Ошибка! Рекурсивная вставка фрагмента "
  etError103      = 103; # "Ошибка чтения файла фрагмента "
  etError104      = 104; # "Ошибка! Аналогичное определение вставки фрагмента уже есть./n /r Новый комментарий не принимается"
  etError105      = 105; # "Ошибка! Неправильная работа с указателем на основную надпись"
  etError106      = 106; # "Ошибка! Неправильная работа с указателем на неуказанную шероховатость"
  etError107      = 107; # "Ошибка! Неправильная работа с указателем на технические требования"
  etError108      = 108; # "Ошибка! Документ должен быть активным"
  etError109      = 109; # "Ошибка! Стиль кривой не найден"
  etError110      = 110; # "Ошибка! Объект должен быть кривой"
  etError111      = 111; # "Ошибка! Стиль текста не найден"
  etError112      = 112; # "Ошибка! Неверно заданы параметры для расчета длины текста"
  etError113      = 113; # "Ошибка! Новый слой должен существовать и быть доступным для редактирования"
  etError114      = 114; # "Ошибка! Номер раздела задан неверно"
  etError115      = 115; # "Ошибка! Стиль спецификации не найден"
  etError116      = 116; # "Ошибка! В текущем документе объект спецификации не найден"
  etError117      = 117; # "Ошибка! Попытка подключить к объекту СП \n\r недопустимый объект"
  etError118      = 118; # "Ошибка! Тип объекта задан неверно"
  etError119      = 119; # "Ошибка! Объект заданного типа не редактируется"
  etError120      = 120; # "Ошибка! Нужно завершить редактирование составного объекта"
  etError121      = 121; # "Ошибка! Объект должен быть таблицей"
  etError122      = 122; # "Ошибка! Объект должен быть допуском формы"
  etError123      = 123; # "Ошибка! Не найден файл для отрисовки слайда"
  etError124      = 124; # "Ошибка! Неверная структура файла для отрисовки слайда"
  etError125      = 125; # "Ошибка! Нужно завершиить редактирование объекта спецификации"
  etError126      = 126; # "Ошибка! Объект должен быть макрообъектом"
  etError127      = 127; # "Ошибка! Попытка поставить в макро \n\r недопустимый объект"
  etError128      = 128; # "Ошибка! Библиотека фрагментов уже закрыта или не открывалась"
  etError129      = 129; # "Ошибка! Библиотека фрагментов уже открыта"
  etError130      = 130; # "Ошибка! Файл библиотеки фрагментов не найден"
  etError131      = 131; # "Ошибка в структуре файла библиотеки фрагментов"
  etError132      = 132; # "Ошибка в имени файла библиотеки фрагментов"
  etError133      = 133; # "Ошибка в имени фрагмента для библиотеки фрагментов"
  etError134      = 134; # "Ошибка! Доступ к фрагменту в библиотеке фрагментов  невозможен"
  etError135      = 135; # "В документе не предусмотрена работа со спецификацией на листе"
  etError136      = 136; # "Ошибка! Не корректный вид типа атрибута"
  etError137      = 137; # "Номер листа спецификации задан неверно"
  etError138      = 138; # "Ошибка! Документ должен быть открыт в видимом режиме"
  etError139      = 139; # "Ошибка при обработке картинки для стиля кривой"
  etError140      = 140; # "Ошибка! Объект должен быть штриховкой"
  etError141      = 141; # "Ошибка! Объект должен быть текстом"
  etError142      = 142; # "В документе не предусмотрена работа со спецификацией на листе"
  etError143      = 143; # "В документе не предусмотрена работа с зонами"
  etError144      = 144; # "Объект спецификации не редактируется"
  etError145      = 145; # "Ошибка! Файл c растровым объектом не найден"
  etError146      = 146; # "Ошибка в определении параметров описания спецификации"
  etError147      = 147; # "Описание спецификации не найдено"
  etError148      = 148; # Имя файла спецификации уже используется в листе"
  etError149      = 149; # Описание спецификации данного типа уже есть в листе"
  etError150      = 150; # "Необходимо завершить текущую операцию"
  etError151      = 151; # "Редактируемый макрообъект удалять нельзя"
  etError152      = 152; # "Ошибка! Служебный файл допусков graphic.tol не найден."
  etError153      = 153; # "Попытка поставить в макро \n\r собственный объект"
  etError154      = 154; # Неправильно задано оформление первого листа спецификации: не указана таблица, предназначенная для спецификации.
  etError155      = 155; # Не найдено оформление первого листа спецификации.
  etError156      = 156; # Неправильно задано оформление первого листа спецификации:\nне найдены ячейки типа \"Для спецификации\".
  etError157      = 157; # Неправильно задано оформление второго и последующих листов спецификации:\nне указана таблица, предназначенная для специ
  etError158      = 158; # Не найдено оформление второго и последующих листов спецификации.
  etError159      = 159; # Неправильно задано оформление второго и последующих листов спецификации:\nне найдены ячейки типа \"Для спецификации\".
  etError160      = 160; # Попытка изменить параметры объкекта только для чтения
  etError161      = 161; # Попытка изменить параметры объкекта только для чтения
  etError162      = 162; # Oшибка создания файла библиотеки
  etError163      = 163; # Текущий документ пустой.\nСохранение в выбранном формате\nпроизводиться не будет.
  etError164      = 164; # Не найдена библиотека стилей спецификаций
  etError165      = 165; # Размер растра превышает допустимый максимальный размер (65536 x 65536)
  etError166      = 166; # Нехватает памяти для создания растра указанного размера
  etError167      = 167; # Выбранный диапазон страниц в документе не существует
  etError168      = 168; # Неверный указатель линии выноски
  etError169      = 169; # Имя документа изменить нельзя.\n\rДокумент с таким именем уже открыт."
  etError170      = 170; # Базовый вид должен быть ассоциативным.
  etError171      = 171; # Базовый объект должен быть стрелкой вида.
  etError172      = 172; # Базовый объект должен быть выносным элементом.
  etError173      = 173; # Неправильно задан цвет.
  etError174      = 174; # Неправильно заданы единицы измерения.
  etError175      = 175; # Нельзя создать пользовательскую панель свойств

  MAXERROR        = 175;

#  Определения для функций GetObjParam и SetObjParam
#  '+'  отмечены объекты, для которых реализованы  GetObjParam и SetObjParam
  ALLPARAM                      = -1;   # все параметры объекта
  SHEET_ALLPARAM                = -2;   # тоже что и  ALLPARAM  но параметры объекта в СК листа
  NURBS_CLAMPED_ALLPARAM        = -5; # параметры нурбса, преобразовать узловой вектор в зажатый
  NURBS_CLAMPED_SHEET_ALLPARAM  = -6; # параметры нурбса в СК листа, преобразовать узловой вектор в зажатый
  VIEW_ALLPARAM                 = -7; # все параметры объекта в СК вида

  ANGLE_ARC_PARAM               = 0;   # параметры дуги по углам
  POINT_ARC_PARAM               = 1;   # параметры дуги по точкам
  ANGLE_ARC_SHEET_PARAM         = 2;   # параметры дуги по углам ( для дуги и эллиптической дуги ) в СК листа
  POINT_ARC_SHEET_PARAM         = 3;   # параметры дуги по точкам ( для дуги и эллиптической дуги ) в СК листа
  ANGLE_ARC_VIEW_PARAM          = 4;   # параметры дуги по углам ( для дуги и эллиптической дуги ) в СК вида
  POINT_ARC_VIEW_PARAM          = 5;   # параметры дуги по точкам ( для дуги и эллиптической дуги ) в СК вида


  VIEW_LAYER_STATE              = 1;   # состояние слоя ,вида
  DOCUMENT_STATE                = 1;   # состояние документа
  DOCUMENT_SIZE                 = 0;   # размер листа
  DIM_TEXT_PARAM                = 0;   # параметры текста для размеров
  DIM_TEXT_PARAM_W              = 6;   # параметры текста для размеров со строками wchar_t
  DIM_SOURSE_PARAM              = 1;   # параметры привязки размера
  DIM_DRAW_PARAM                = 2;   # параметры отрисовки размера
  DIM_VALUE                     = 3;   # значение размера - double
  DIM_PARTS                     = 4;   # составляющие части для размеров struct DimensionPartsParam
  SHEET_DIM_PARTS               = 5;   # составляющие части для размеров struct DimensionPartsParam в СК листа
  TECHNICAL_DEMAND_PAR          =-1;   # параметры технических требований -
  TT_FIRST_STR                  = 1000;# начало отсчета для получения или замены текста ТТ по строкам
  CONIC_PARAM                   = 2;   # параметры для построения конического сечения ( для эллипса и эллтптической дуги )
  SPC_TUNING_PARAM              = 0;   # параметры настроек для стиля СП
  HATCH_PARAM_EX                = 0;   # параметры штриховки расширенные
  ASSOCIATION_VIEW_PARAM        = 0;   # параметры ассоциативного вида
  DIM_SOURSE_VIEWPARAM          = 7;   # параметры привязки размера в ситеме координат вида
  DIM_DRAW_VIEWPARAM            = 8;   # параметры отрисовки размера в ситеме координат вида
  DIM_SOURSE_SHEETPARAM         = 9;   # параметры привязки размера в ситеме координат листа
  DIM_DRAW_SHEETPARAM           = 10;  # параметры отрисовки размера в ситеме координат листа

# объекты
  ALL_OBJ               = 0;  # все объекты, кроме вспомогательных, которые могут входить в вид                    -
  LINESEG_OBJ           = 1;  # отрезок
  CIRCLE_OBJ            = 2;  # окружность
  ARC_OBJ               = 3;  # дуга
  TEXT_OBJ              = 4;  # текст
  POINT_OBJ             = 5;  # точка
  HATCH_OBJ             = 7;  # штриховка
  BEZIER_OBJ            = 8;  # bezier сплайн
  LDIMENSION_OBJ        = 9;  # линейный размер
  ADIMENSION_OBJ        = 10; # угловой размер
  DDIMENSION_OBJ        = 13; # диаметральный размер
  RDIMENSION_OBJ        = 14; # радиальный размер
  RBREAKDIMENSION_OBJ   = 15; # радиальный размер с изломом
  ROUGH_OBJ             = 16; # шероховатость
  BASE_OBJ              = 17; # база
  WPOINTER_OBJ          = 18; # стрелка вида
  CUT_OBJ               = 19; # линия разреза
  LEADER_OBJ            = 20; # простая линия выноски
  POSLEADER_OBJ         = 21; # линия выноски для обозначения позиции
  BRANDLEADER_OBJ       = 22; # линия выноски для обозначения клеймения
  MARKERLEADER_OBJ      = 23; # линия выноски для обозначения маркирования
  TOLERANCE_OBJ         = 24; # допуск формы
  TABLE_OBJ             = 25; # таблица
  CONTOUR_OBJ           = 26; # контур
  MACRO_OBJ             = 27; # нетипизированный макроэлемент
  LINE_OBJ              = 28; # линия
  LAYER_OBJ             = 29; # слой
  FRAGMENT_OBJ          = 30; # вставной фрагмент
  POLYLINE_OBJ          = 31; # полилиния
  ELLIPSE_OBJ           = 32; # эллипс
  NURBS_OBJ             = 33; # nurbs сплайн
  ELLIPSE_ARC_OBJ       = 34; # дуга эллипса
  RECTANGLE_OBJ         = 35; # прямоугольник
  REGULARPOLYGON_OBJ    = 36; # многоугольник
  EQUID_OBJ             = 37; # эквидистанта
  LBREAKDIMENSION_OBJ   = 38; # линейный размер с обрывом
  ABREAKDIMENSION_OBJ   = 39; # угловой размер с обрывом
  ORDINATEDIMENSION_OBJ = 40; # размер высоты
  COLORFILL_OBJ         = 41; # фоновая заливка цветом
  CENTREMARKER_OBJ      = 42; # обозначение центра
  ARCDIMENSION_OBJ      = 43; # размер длины дуги
  SPC_OBJ               = 44; # объект спецификации
  RASTER_OBJ            = 45; # растровый объект
  CHANGE_LEADER_OBJ     = 46; # Обозначение изменения
  REMOTE_ELEMENT_OBJ    = 47; # выносной элемент
  AXISLINE_OBJ          = 48; # Осевая линия
  OLEOBJECT_OBJ         = 49; # Вставка ole объекта
  KNOTNUMBER_OBJ        = 50; # объект номер узла              -
  BRACE_OBJ             = 51; # объект фигурная скобка         -
  POSNUM_OBJ            = 52; # марка/позиционное обозначение с линией-выноской -
  MARKONLDR_OBJ         = 53; # марка/позиционное обозначение на линии          -
  MARKWOLDR_OBJ         = 54; # марка/позиционное обозначение без линии-выноски -
  WAVELINE_OBJ          = 55; # волнистая линия                -
  DIRAXIS_OBJ           = 56; # прямая ось                     -
  BROKENLINE_OBJ        = 57; # линия обрыва с изломами        -
  CIRCLEAXIS_OBJ        = 58; # круговая ось                   -
  ARCAXIS_OBJ           = 59; # дуговая ось                    -
  CUTUNITMARKING        = 60; # Обозначение узла в сечении     -
  UNITMARKING           = 61; # Обозначение узла               -
  MULTITEXTLEADER       = 62; # Выносная надпись к многослойным конструкциям.      -
  EXTERNALVIEW_OBJ      = 63; # Вставка внешнего вида                              -
  ANNLINESEG_OBJ        = 64; # Аннотационный отрезок                 +- Для GetObjParam используется структура LineSegParam
  ANNCIRCLE_OBJ         = 65; # Аннотационная окружность              +- Для GetObjParam используется структура CircleParam
  ANNELLIPSE_OBJ        = 66; # Аннотационный эллипс                  +- Для GetObjParam используется структура EllipseParam
  ANNARC_OBJ            = 67; # Аннотационная дуга                    +- Для GetObjParam используется структура ArcParam
  ANNELLIPSE_ARC_OBJ    = 68; # Аннотационная дуга эллипса            +- Для GetObjParam используется структура EllipseArcParam
  ANNPOLYLINE_OBJ       = 69; # Аннотационная полилиния               +- Для GetObjParam используется структура PolylineParam
  ANNPOINT_OBJ          = 70; # Аннотационная точка                   +- Для GetObjParam используется структура PointParam
  ANNTEXT_OBJ           = 71; # Текст с аннотационной точкой привязки +- Для GetObjParam используется структура TextParam
  MULTILINE_OBJ         = 72; # Мультилиния                    -
  BUILDINGCUTLINE_OBJ   = 73; # Линия разреза/сечения для СПДС + используется структура CutLineParam
  ATTACHED_LEADER_OBJ   = 74; # Присоединенная линия выноски ( не имеет текстов )  +
  CONDITIONCROSSING_OBJ = 75; # Условное пересечение           -
  REPORTTABLE_OBJ       = 76; # ассоциативная таблица отчета
  EMBODIMENTSTABLE_OBJ  = 77; # таблица исполнений
  SPECIALCURVE_OBJ      = 78; # Кривая общего вида
  ARRAYPARAMTABLE_OBJ   = 79; # Таблица параметров массива
  NURBS_BY_POINTS_OBJ   = 80; # NURBS-кривая по точкам                        +- Для GetObjParam используется структура NurbsParam
  CONIC_CURVE_OBJ       = 81; # Коническая кривая                             +- Для GetObjParam используется структура NurbsParam
  CIRCULAR_CENTRES_OBJ  = 84; # Круговая сетка центров
  LINEAR_CENTRES_OBJ    = 85; # Линейная сетка центров
  ELLIPSE_ARC_AXIS_OBJ  = 86; # Дуговая осевая линия


  MAX_VIEWTIP_SEARCH    = 87; # верхняя граница типов поиска для объектов вида  -

  SPECIFICATION_OBJ     = 121; # спецификация на листе
  SPECROUGH_OBJ         = 122; # неуказанная шероховатость
  VIEW_OBJ              = 123; # вид
  DOCUMENT_OBJ          = 124; # документ  графический
  TECHNICALDEMAND_OBJ   = 125; # технические требования
  STAMP_OBJ             = 126; # штамп
  SELECT_GROUP_OBJ      = 127; # группа селектирования
  NAME_GROUP_OBJ        = 128; # именная группа
  WORK_GROUP_OBJ        = 129; # рабочая группа
  SPC_DOCUMENT_OBJ      = 130; # документ  спецификация
  D3_DOCUMENT_OBJ       = 131; # 3d документ  модели или сборки
  CHANGE_LIST_OBJ       = 132; # таблица изменений
  TXT_DOCUMENT_OBJ      = 133; # текстовый документ
  ALL_DOCUMENTS         = 134; # документы всех типов

  MAX_TIP_SEARCH        = 134;  # верхняя граница типов поиска
  ALL_OBJ_SHOW_ORDER    = -1000; # все объекты которые могут входить в вид в порядке отрисовки

# типы БД
  ODBC_DB = 0;
  TXT_DB  = 1;

  TXT_CHAR   = 1;
  TXT_USHORT = 2;
  TXT_SSHORT = 3;
  TXT_SLONG  = 4;
  TXT_ULONG  = 5;
  TXT_LONG   = 6;
  TXT_FLOAT  = 7;
  TXT_DOUBLE = 8;
  TXT_INT    = 9;
  TXT_ALL    = 0;
  TXT_INDEX  = 'Index1000';

# состояние для вида
  stACTIVE    = 0;  # слоя, документа
  stREADONLY  = 1;  # слоя
  stINVISIBLE = 2;  # слоя
  stCURRENT   = 3;  # слоя
  stPASSIVE   = 1;  # документа

# Определения для функции ksSytemPath
  sptSYSTEM_FILES = 0; # выдать путь на каталог системных файлов
  sptLIBS_FILES   = 1; # выдать путь на каталог файлов библиотек
  sptTEMP_FILES   = 2; # выдать путь на каталог сохранения временных файлов
  sptCONFIG_FILES = 3; # выдать путь на каталог сохранения конфигурации системы
  sptINI_FILE     = 4; # выдать полное имя INI-файла системы
  sptBIN_FILE 	  = 5; # Выдать путь на каталог исполняемых файлов системы

# oпределения для результата функции SystemControlStart
  scsSTOPPED_FOR_MENU_COMMAND      =  1; # выполнена команда меню "Остановить работу библиотеки"
  scsSTOPPED_FOR_SYSTEM_STOP       =  0; # идет закрытие задачи
  scsSTOPPED_FOR_ITSELF            = -1; # вызов функции SystemControlStop из-под библиотеки
  scsSTOPPED_FOR_START_THIS_LIB    = -2; # принудительный останов при запуске той же библиотеки
  scsSTOPPED_FOR_START_ANOTHER_LIB = -3; # принудительный останов при запуске другой библиотеки

# oпределения флагов для текста
  INVARIABLE         =  0;   # не менять флаги текста
  NUMERATOR          =  0x1;  # числитель
  DENOMINATOR        =  0x2;  # знаменатель
  END_FRACTION       =  0x3;  # конец дроби
  UPPER_DEVIAT       =  0x4;  # верхнее отклонение
  LOWER_DEVIAT       =  0x5;  # нижнее отклонение
  END_DEVIAT         =  0x6;  # конец  отклонений
  S_BASE             =  0x7;  # основание выражения типа суммы
  S_UPPER_INDEX      =  0x8;  # верхний индекс выражения типа суммы
  S_LOWER_INDEX      =  0x9;  # нижний индекс выражения типа суммы
  S_END              =  0x10; # конец выражения типа суммы
  SPECIAL_SYMBOL     =  0x11; # спецзнак
  SPECIAL_SYMBOL_END =  0x12; # для спецзнаков с текстом
  RETURN_BEGIN       =  0x13; # начало для ввода следующих строк в спецзнаке с текстом, дробях, отклонениях
  RETURN_DOWN        =  0x14; # для ввода следующих строк в спецзнаке с текстом, дробях, отклонениях
  RETURN_RIGHT       =  0x15; # для ввода строк справа в спецзнаке с текстом, дробях, отклонениях
  TAB                =  0x16; # табуляция по текущему стилю
  FONT_SYMBOL        =  0x17; # символ фонта
  FONT_SYMBOL_W      =  0x2017; #символ фонта Unicode
  HYPER_TEXT         =  0x2000; #ссылка на текст или положение объекта

  ITALIC_ON          = 0x40;  # включить наклон
  ITALIC_OFF         = 0x80;  # выключть наклон
  BOLD_ON            = 0x100; # включить толщину
  BOLD_OFF           = 0x200; # выключть толщину
  UNDERLINE_ON       = 0x400; # включить подчеркивание
  UNDERLINE_OFF      = 0x800; # выключть подчеркивание
  NEW_LINE           = 0x1000; # новая строка в параграфе

  LIKE_BASIC_LINE = 0x10; # параметры пера как у основной линии
  LIKE_THIN_LINE  = 0x20; # параметры пера как у тонкой линии
  LIKE_HEAVY_LINE = 0x30; # параметры пера как у утолщенной линии

  FONT_NAME      =  1; # имя фонта
  NARROWING      =  2; # коэффициент сужения фонта
  HEIGHT         =  3; # высота фонта
  COLOR          =  4; # цвет текста
  SPECIAL        =  5; # спецзнак
  FRACTION_TYPE  =  6; # высота дроби по отношению к тексту 1-полная высота 2-в 1.5 раза меньше 3-в 2 раза меньше
  SUM_TYPE       =  7; # высота выражения типа суммы по отношению к тексту 1-полная высота 2-в 1.5 раза больше

# типы предопределенных динамических массивов
  CHAR_STR_ARR           = 1 ; # массив указателей на строки символов
  POINT_ARR              = 2 ; # массив указателей на математические точки -структура MathPointParam
  CURVE_PATTERN_ARR      = 2 ; # массив указателей на участки штриховой линии -структура CurvePattern
  TEXT_LINE_ARR          = 3 ; # массив строк текста - структура TextLineParam
  TEXT_ITEM_ARR          = 4 ; # массив компонент строк текста структура TextItemParam
  ATTR_COLUMN_ARR        = 5 ; # массив колонок аттрибутов- структура  ColumnInfo
  USER_ARR               = 6 ; # пользовательский массив
  POLYLINE_ARR           = 7 ; # массив полилиний-(указателей массивов POINT_ARR)
  RECT_ARR               = 8 ; # массив габаритных прямоугольников-(структура RectParam)
  LIBRARY_STYLE_ARR      = 9 ; # массив структур параметров для стиля в библиотеке стилей( LibraryStyleParam )
  VARIABLE_ARR           = 10; # массив структур параметров параметрических переменных( VariableParam )
  CURVE_PATTERN_ARR_EX   = 11; # массив указателей на участки штриховой линии -структура CurvePatternEx
  LIBRARY_ATTR_TYPE_ARR  = 12; # массив структур параметров для типа атрибута в библиотеке типов атрибутов( LibraryAttrTypeParam )
  NURBS_POINT_ARR        = 13; # массив структур NurbsPointParam
  DOUBLE_ARR             = 14; # массив duuble
  CONSTRAIN_ARR          = 15; # массив параметрических ограничений - структура ConstrainParam
  CORNER_ARR             = 16; # массив структур параметров углов CornerParam для прямоугольников и многоугольников
  DOC_SPCOBJ_ARR         = 17; # массив структур параметров прикрепленных документов к объекту спецификации
  SPCSUBSECTION_ARR      = 18; # динамический массив структур параметров подраздела спецификации SpcSubSectionParam
  SPCTUNINGSEC_ARR       = 19; # динамический массив структур параметров настройки раздела спецификации SpcTuningSectionParam
  SPCSTYLECOLUMN_ARR     = 20; # динамический массив структур параметров стиля колонки таблицы спецификации SpcStyleColumnParam
  SPCSTYLESEC_ARR        = 21; # динамический массив структур параметров стиля разделa спецификации SpcStyleSectionParam
  QUALITYITEM_ARR        = 22; # динамический массив структур QualityItemParam - запись об одном интервале для какого-то квалитета
  LTVARIANT_ARR          = 23; # динамический массив структур LtVariant
  TOLERANCEBRANCH_ARR    = 24; # динамический массив структур ToleranceBranch
  HATCHLINE_ARR          = 25; # динамический массив структур HatchLineParam
  TREENODEPARAM_ARR      = 26; # динамический массив структур узла дерева TreeNodeParam
  CHAR_STR_ARR_W         = 27; # динамический массив указателей на строки символов типа wchar

# типы данных для определения атрибутов
  CHAR_ATTR_TYPE    = 1;
  UCHAR_ATTR_TYPE   = 2;
  INT_ATTR_TYPE     = 3;
  UINT_ATTR_TYPE    = 4;
  LINT_ATTR_TYPE    = 5;
  FLOAT_ATTR_TYPE   = 6;
  DOUBLE_ATTR_TYPE  = 7;
  STRING_ATTR_TYPE  = 8; # строка фиксированной длины MAX_TEXT_LENGTH
  RECORD_ATTR_TYPE  = 9;

# oпределения для линейного размера
  _AUTONOMINAL       =  0x1;   # простановка размера автоматическая
  _RECTTEXT          =  0x2;   # текст в рамочке
  _PREFIX            =  0x4;   # есть текст до номинала
  _NOMINALOFF        =  0x8;   # нет  номинала
  _TOLERANCE         =  0x10;  # квалитет проставлять
  _DEVIATION         =  0x20;  # отклонения проставлять
  _UNIT              =  0x40;  # единица измерения
  _SUFFIX            =  0x80;  # есть текст после номинала
  _DEVIATION_INFORM  =  0x100; # при включенном _DEVIATION, отклонения есть в массиве текстов( даже если не ручное проставление отклонений).
  _UNDER_LINE        =  0x200; # >0 размер с подчеркиванием

  INDICATIN_TEXT_LINE_ARR = 0xFFFF; # для шероховаиости, позиционной линии выноски, маркировки и клеймения
                                    # признак, что для текста используется динамический массив TEXT_LINE_ARR
  _BRACKETS          = 0x400; # >0 размер в скобках
  _SQUARE_BRACKETS   = 0x800; # >0 размер в квадратных скобках, используется вместе с _BRACKETS

# типы стилей
  CURVE_STYLE    = 1; # стиль криивых
  HATCH_STYLE    = 2; # стиль штриховок
  TEXT_STYLE     = 3; # стиль текста
  STAMP_STYLE    = 4; # стиль штампа
  CURVE_STYLE_EX = 5; # стиль кривых расширенный

  LIKE_BASIC_LINE = 0x10; # параметры пера как у  основной линии
  LIKE_THIN_LINE  = 0x20; # параметры пера как у  тонкой линии
  LIKE_HEAVY_LINE = 0x30; # параметры пера как у  утолщенной линии

# oпределения для функций GetSysOptions и SetSysOptions
  DIMENTION_OPTIONS          = 1; # Настройки размера
  SNAP_OPTIONS               = 1; # Настройки привязок
  ARROWFILLING_OPTIONS       = 2; # Зачернять стрелки ?
  SHEET_OPTIONS              = 3; # Параметры листа документов
  SHEET_OPTIONS_EX           = 4; # Параметры листа документа
  LENGTHUNITS_OPTIONS        = 5; # Настройки единиц измерений
  SNAP_OPTIONS_EX            = 6; # Настройки привязок активного документа
  VIEWCOLOR_OPTIONS          = 7; # Настройки цвета фона рабочего поля (2d - документов)
  TEXTEDIT_VIEWCOLOR_OPTIONS = 8; # Настройки цвета фона редактирования текста
  MODEL_VIEWCOLOR_OPTIONS    = 9; # Настройки цвета фона для моделей
  OVERLAP_OBJECT_OPTIONS     =10; # Настройки перекрывающихся объектов
  DIMENTION_OPTIONS_EX       =11; # Настройки размера

# типы колонок для спецификации
  SPC_CLM_FORMAT   = 1;  # формат
  SPC_CLM_ZONE     = 2;  # зона
  SPC_CLM_POS      = 3;  # позиция
  SPC_CLM_MARK     = 4;  # обозначение
  SPC_CLM_NAME     = 5;  # наименование
  SPC_CLM_COUNT    = 6;  # количество
  SPC_CLM_NOTE     = 7;  # примечание
  SPC_CLM_MASSA    = 8;  # масса
  SPC_CLM_MATERIAL = 9;  # материал
  SPC_CLM_USER     = 10; # пользовательская
  SPC_CLM_KOD      = 11; # код
  SPC_CLM_FACTORY  = 12; # завод изготовитель

#типы значений для колонки спецификации
  SPC_INT    = 1; # целый
  SPC_DOUBLE = 2; # вещественный
  SPC_STRING = 3; # строка
  SPC_RECORD = 4; # запись

# типы библиотек стилей
  CURVE_STYLE_LIBRARY           =  1; # библиотека стилей кривых (*.lcs)
  HATCH_STYLE_LIBRARY           =  2; # библиотека стилей штриховок (*.lhs)
  TEXT_STYLE_LIBRARY            =  3; # библиотека стилей текстов   (*.lts)
  STAMP_LAYOUT_STYLE_LIBRARY    =  4; # библиотека стилей описаний штампов (*.lyt)
  GRAPHIC_LAYOUT_STYLE_LIBRARY  =  5; # библиотека стилей оформлений графических документов (*.lyt)
  TEXT_LAYOUT_STYLE_LIBRARY     =  6; # библиотека стилей оформлений текстовых документов (*.lyt)
  SPC_LAYOUT_STYLE_LIBRARY      =  7; # библиотека стилей оформлений спецификаций (*.lyt)

# размерности и типы детали для рассчета массо-ценровочных характеристик
  ST_MIX_MM  = 0x1;  # миллиметры
  ST_MIX_SM  =  0;  # сантиметры
  ST_MIX_DM  = 0x2;  # дециметры
  ST_MIX_M   = 0x3;  # метры
  ST_MIX_GR  =  0;  # граммы
  ST_MIX_KG  = 0x10; # килограммы
  ST_MIX_EXT =  0;  # выдавливание
  ST_MIX_RV  = 0x20; # вращение

# тип локальной привязки
  SN_NEAREST_POINT  = 1; # ближайшая точка
  SN_NEAREST_MIDDLE = 2; # середина
  SN_CENTRE         = 3; # центр
  SN_INTERSECT      = 4; # пересечение
  SN_GRID           = 5; # по сетке
  SN_XY_ALIGN       = 6; # выравнивание
  SN_ANGLE          = 7; # угловая привязка
  SN_POINT_CURVE    = 8; # точка на кривой

# типы общих настроек для привязок
  SN_DYNAMICALLY                = 0x1; # привязки отслеживать динамически
  SN_ASSISTANT                  = 0x2; # писать текст
  SN_BACKGROUND_LAYER           = 0x4; # учитывать фоновые слои и виды
  SN_SUSPENDED                  = 0x8; # подавить привязки
  SN_VISIBLE_GRID_POINTS_ONLY   = 0x10; # привязка только к видимым точкам сетки

# типы параметрических ограничений
  CONSTRAINT_FIXED_POINT                =  1; # фиксировать точку
  CONSTRAINT_POINT_ON_CURVE             =  2; # точка на кривой
  CONSTRAINT_HORIZONTAL                 =  3; # горизонталь
  CONSTRAINT_VERTICAL                   =  4; # вертикаль
  CONSTRAINT_PARALLEL                   =  5; # параллельность двух прямых или отрезков
  CONSTRAINT_PERPENDICULAR              =  6; # перпендикулярность двух прямых или отрезков
  CONSTRAINT_EQUAL_LENGTH               =  7; # равенство длин двух отрезков
  CONSTRAINT_EQUAL_RADIUS               =  8; # равенство радиусов двух дуг/окружностей
  CONSTRAINT_HOR_ALIGN_POINTS           =  9; # выравнивать две точки по горизонтали
  CONSTRAINT_VER_ALIGN_POINTS           = 10; # выравнивать две точки по вертикали
  CONSTRAINT_MERGE_POINTS               = 11; # совпадение двух точек
  CONSTRAINT_TANGENT_TWO_CURVES         = 15; # касание двух кривых
  CONSTRAINT_SYMMETRY_TWO_POINTS        = 16; # симетрия двух точек
  CONSTRAINT_COLLINEAR                  = 17; # колинеарность отрезков
  CONSTRAINT_FIXED_ANGLE                = 18; # фиксированный угол
  CONSTRAINT_FIXED_LENGHT               = 19; # фиксированная длина
  CONSTRAINT_POINT_ON_CURVE_MIDDLE      = 20; # точка на серидине кривой
  CONSTRAINT_BISECTOR                   = 21; # биссектриса
  CONSTRAINT_CONCENTRICITY              = 22; # совпадение центров окружностей, дуг, эллипсов и точек

# типы объектов спецификации
  SPC_BASE_OBJECT  = 1; # базовый объект ( редактируется пользователем )
  SPC_COMMENT      = 2; # комментарий ( редактируется пользователем )
  SPC_SECTION_NAME = 3; # наименование раздела ( создается по стилю СП автоматически )
  SPC_BLOCK_NAME   = 4; # наименование блока исполнений ( создается по стилю СП автоматически )
  SPC_RESERVE_STR  = 5; # резервная строка ( создается по стилю СП автоматически )
  SPC_EMPTY_STR    = 6; # пустая строка ( создается по стилю СП автоматически )

# типы сортировки
  SPC_SORT_OFF      = 0; # нет сортировки
  SPC_SORT_COMPOS   = 1; # составная сортировка
  SPC_SORT_ALPHABET = 2; # сортировка по алфавиту
  SPC_SORT_UP       = 3; # сортировка по возрастанию колонок
  SPC_SORT_DOCUMENT = 4; # сортировка раздела документация
  SPC_SORT_DOWN     = 5; # сортировка по убыванию колонок
  SPC_SORT_COMPOSDOWN = 6; # составная сортировка по убыванию

# типы специальных символов ( аннотационный объект )
  ARROW_INSIDE_SYMBOL       = 1;  # стрелка изнутри
  ARROW_OUT_SIDE_SYMBOL     = 2;  # стрелка снаружи
  TICK_TAIL_SYMBOL          = 3;  # засечка с продолжением кривой (с хвостиком)
  UP_HALF_ARROW_SYMBOL      = 4;  # верхняя половина стрелки изнутри
  DOWN_HALF_ARROW_SYMBOL    = 5;  # нижняя половина стрелки изнутри
  BIG_ARROW_INSIDE_SYMBOL   = 6;  # большая стрелка изнутри (7мм)
  ARROW_ORDINATE_DIM_SYMBOL = 7;  # стрелка для размера высоты(штрихи длиной 4 мм под углом 45 гр)
  TRIANGLE_SYMBOL           = 8;  # треугольник по напр-нию кривой
  CIRCLE_RAD2_SYMBOL        = 9;  # окружность радиусом 2 мм тонкой линией - для шер-сти и линии-выноски
  CENTRE_MARKER_SYMBOL      = 10; # обозначение фиктивного центра в виде большого креста
  GLUE_SIGN_SYMBOL          = 11; # знак склеивания
  SOLDER_SIGN_SYMBOL        = 12; # знак пайки
  SEWING_SIGN_SYMBOL        = 13; # знак сшивания
  CRAMP_SIGN_SYMBOL         = 14; # знак соединения внахлестку металл.скобами
  CORNER_CRAMP_SIGN_SYMBOL  = 15; # знак углового соединения металл.скобами
  MONTAGE_JOINT_SYMBOL      = 16; # знак монтажного шва
  TICK_SYMBOL               = 17; # засечка без продолжения кривой (без хвостика)
  TRIANGLE_CURR_CS          = 18; # треугольник по текущей СК - для базы
  ARROW_CLOSED_INSIDE       = 19; # закрытая стрелка изнутри
  ARROW_CLOSED_OUTSIDE      = 20; # закрытая стрелка снаружи
  ARROW_OPEN_INSIDE         = 21; # открытая стрелка изнутри
  ARROW_OPEN_OUTSIDE        = 22; # открытая стрелка снаружи
  ARROW_RIGHTANGLE_INSIDE   = 23; # стрелка 90 град изнутри
  ARROW_RIGHTANGLE_OUTSIDE  = 24; # стрелка 90 град снаружи
  SYMBOL_DOT                = 25; # точка (диаметр равен длины стрелки размера)
  SYMBOL_SMALLDOT           = 26; # точка маленькая (диаметр равен 0.6 длины стрелки размера)
  AUXILIARY_POINT           = 27; # вспомогательная точка
  LEFT_TICK_SYMBOL          = 28; # засечка с наклоном влево

#------------------------------------------------------------------------------
# Битовые флаги для функции ksSetMacroParam;
# указание какой тип редактирования поддерживает макро
# ---
  MP_DBL_CLICK_OFF   = 0x01; #>0 редактирование по двойному нажанию выключено
  MP_HOTPOINTS       = 0x02; #>0 интерфейс hot точек включен
  MP_EXTERN_EDIT     = 0x04; #>0 интерфейс внешнего управления

# типы документов DocType
  lt_DocSheetStandart = 1;  # чертеж стандартный
  lt_DocSheetUser     = 2;  # чертеж нестандартный
  lt_DocFragment      = 3;  # фрагмент
  lt_DocSpc           = 4;  # спецификация
  lt_DocPart3D        = 5;  # 3d-документ модель
  lt_DocAssemble3D    = 6;  # 3d-документ сборка
  lt_DocTxtStandart   = 7;  # текстовый документ стандартный
  lt_DocTxtUser       = 8;  # текстовый документ нестандартный
  lt_DocSpcUser       = 9;  # спецификация нестандартный формат

# система квалитета LtQualSystem
  lt_qsShaft = 1; # вала
  lt_qsHole  = 2; # отверстия

# квалитеты LtQualDir
  lt_qdPreferable = 1; # предпочтительные
  lt_qdBasic      = 2; # основные
  lt_qdAdditional = 3; # дополнительные

# типы данных для LtVariant - LtVariantType
  ltv_Char   = 1;  # символ
  ltv_UChar  = 2;  # байт
  ltv_Int    = 3;  # целое
  ltv_UInt   = 4;  # беззнаковое целое
  ltv_Long   = 5;  # длинное целое
  ltv_Float  = 6;  # вешественное
  ltv_Double = 7;  # двойное вешественное
  ltv_Str    = 8;  # строка 255 символов
  ltv_NoUsed = 9;  # пока не используется
  ltv_Short  = 10; # короткое целое

# типы размеров высоты
  OD_FRONTVIEW      = 0x00; # для вида спереди, с полкой и стрелкой, возможна выносная линия
  OD_TOPVIEW        = 0x08; # для вида сверху без линии-выноски - только текст в рамке
  OD_TOPVIEWLEADER  = 0x10; # для вида сверху с линией-выноской

#-----------------------------------------------------------------------------
#определения для конвертации в растровый формат
# ---
  FORMAT_BMP  = 0;
  FORMAT_GIF  = 1;
  FORMAT_JPG  = 2;
  FORMAT_PNG  = 3;
  FORMAT_TIF  = 4;
  FORMAT_TGA  = 5;
  FORMAT_PCX  = 6;
  FORMAT_WMF  = 16;
  FORMAT_EMF  = 17;

#-----------------------------------------------------------------------------
#определения для настройки цвета растрового формата
# ---
  BLACKWHITE  = 0;   #цвет черный
  COLORVIEW   = 1;   #цвет установленный для вида
  COLORLAYER  = 2;   #цвет установленный для слоя
  COLOROBJECT = 3;   #цвет установленный для объекта

#-----------------------------------------------------------------------------
# орределения бит на пиксел для конвертации в растровый формат
# ---
  BPP_COLOR_01 = 1;  #"Черный"
  BPP_COLOR_02 = 2;  #"4 цвета"
  BPP_COLOR_04 = 4;  #"16 цветов"
  BPP_COLOR_08 = 8;  #"256 цветов"
  BPP_COLOR_16 = 16; #"16 разрядов"
  BPP_COLOR_24 = 24; #"24 разряда"
  BPP_COLOR_32 = 32; #"32 разряда"

# перечисление возможных типов узла дерева библиотеки документов LtNodeType
  tn_root      = 0;  # корень дерева
  tn_dir       = 1;  # папка (директория)
  tn_file      = 2;  # документ (файл)

# Типы видов LtViewType
  vt_System    = 0;  # системный вид (с номером 0, создается автоматически, существует всегда)
  vt_Normal    = 1;  # обычный вид
  vt_Arbitrary = 2;  # произвольный вид
  vt_Standart  = 3;  # стандартный вид
  vt_Projected = 4;  # проекционный
  vt_Arrow     = 5;  # по стрелке
  vt_Remote    = 6;  # выносной вид
  vt_Section   = 7;  # разрез\сечение

# Типы стандартных видов
  VIEW_FRONT   = 0x01;  #  Спереди
  VIEW_REAR    = 0x02;  #  Сзади
  VIEW_UP      = 0x04;  #  Сверху
  VIEW_DOWN    = 0x08;  #  Снизу
  VIEW_LEFT    = 0x10;  #  Слева
  VIEW_RIGHT   = 0x20;  #  Справа
  VIEW_ISO     = 0x40;  #  Изометрия

# типы значка объекта "Выносной элемент" LtRemoteElmSignType
  re_Circle    = 0;    # окружность
  re_Rectangle = 1;    # прямоугольник
  re_Ballon    = 2;    # скругленный прямоугольник

# Тип изменения порядка объектов
#enum ChangeOrderType
  co_Top          = 1; # Выше всех
  co_Bottom       = 2; # Ниже всех
  co_BeforeObject = 3; # Перед объектом
  co_AfterObject  = 4; # За объектом
  co_UpLevel      = 5; # На уровень вперед
  co_DownLevel    = 6; # На уровень назад

# типы структур создаваемых методом GetParamStruct объекта KompasObject - StructType2D
  ko_Type1                 = 1;   # интерфейс ksType1                 структура параметров для сдвига группы
  ko_Type2                 = 2;   # интерфейс ksType2                 структура параметров для сдвига группы
  ko_Type3                 = 3;   # интерфейс ksType3                 структура параметров для сдвига группы
  ko_Type5                 = 4;   # интерфейс ksType5                 структура параметров для сдвига группы
  ko_Type6                 = 5;   # интерфейс ksType6                 структура параметров для сдвига группы
  ko_Phantom               = 6;   # интерфейс ksPhantom               структура параметров фантома
  ko_PlacementParam        = 7;   # интерфейс ksPlacementParam        структура параметров местоположения
  ko_ViewParam             = 8;   # интерфейс ksViewParam             структура параметров вида
  ko_LayerParam            = 9;   # интерфейс ksLayerParam            структура параметров слоя
  ko_RequestInfo           = 10;  # интерфейс ksRequestInfo           структура параметров запроса
  ko_LineSegParam          = 11;  # интерфейс ksLineSegParam          структура параметров отрезока
  ko_ArcByAngleParam       = 12;  # интерфейс ksArcByAngleParam       структура параметров дуги по центру и углам
  ko_ArcByPointParam       = 13;  # интерфейс ksArcByPointParam       структура параметров дуги по центу и конечным точкам
  ko_MathPointParam        = 14;  # интерфейс ksMathPointParam        структура параметров математической точки
  ko_RectParam             = 15;  # интерфейс ksRectParam             структура параметров габаритного прямоугольника
  ko_PointParam            = 16;  # интерфейс ksPointParam            структура параметров  точки
  ko_BezierPointParam      = 17;  # интерфейс ksBezierPointParam      структура параметров  узла  для  Bezier - кривой
  ko_NurbsPointParam       = 18;  # интерфейс ksNurbsPointParam       структура параметров Nurbs-точки
  ko_BezierParam           = 19;  # интерфейс ksBezierParam           структура параметров Bezier сплайна
  ko_CircleParam           = 20;  # интерфейс ksCircleParam           структура параметров окружности
  ko_LineParam             = 21;  # интерфейс ksLineParam             структура параметров линии
  ko_EllipseParam          = 22;  # интерфейс ksEllipseParam          структура параметров эллипса
  ko_EllipsArcParam        = 23;  # интерфейс ksEllipsArcParam        структура параметров дуги эллипса
  ko_EllipsArcParam1       = 24;  # интерфейс ksEllipsArcParam1       структура параметров дуги эллипса
  ko_EquidParam            = 25;  # интерфейс ksEquidParam            структура параметров эквидистанты
  ko_HatchParam            = 26;  # интерфейс ksHatchParam            структура параметров штриховки
  ko_ParagraphParam        = 27;  # интерфейс ksParagraphParam        структура параметров параграфа текста
  ko_TextParam             = 28;  # интерфейс ksTextParam             структура параметров текста
  ko_TextLineParam         = 29;  # интерфейс ksTextLineParam         структура параметров строки текста
  ko_TextItemFont          = 30;  # интерфейс ksTextItemFont          структура параметров фонта компоненты строки текста
  ko_TextItemParam         = 31;  # интерфейс ksTextItemParam         структура параметров компоненты строки текста
  ko_StandartSheet         = 32;  # интерфейс ksStandartSheet         структура параметров стандартного листа
  ko_SheetSize             = 33;  # интерфейс ksSheetSize             структура параметров нестандартного листа
  ko_SheetPar              = 34;  # интерфейс ksSheetPar              структура параметров оформления
  ko_DocumentParam         = 35;  # интерфейс ksDocumentParam         структура параметров документа
  ko_ColumnInfoParam       = 36;  # интерфейс ksColumnInfoParam       структура параметров колонки аттрибута
  ko_AttributeType         = 37;  # интерфейс ksAttributeType         структура параметров типа аттрибута
  ko_Attribute             = 38;  # интерфейс ksAttribute             структура параметров колонки аттрибута
  ko_LibraryAttrTypeParam  = 39;  # интерфейс ksLibraryAttrTypeParam  структура параметров
  ko_TAN                   = 40;  # интерфейс ksTAN                   структура параметров точек пересечения
  ko_CON                   = 41;  # интерфейс ksCON                   структура параметров точек пересечения
  ko_DimText               = 42;  # интерфейс ksDimText               структура размерной надписи
  ko_LDimSource            = 43;  # интерфейс ksLDimSource            структура параметров привязки линейного  размера
  ko_DimDrawing            = 44;  # интерфейс ksDimDrawing            структура параметров отрисовки линейного и углового размеров
  ko_LDimParam             = 45;  # интерфейс ksLDimParam             структура параметров линейного размера
  ko_LBreakDimSource       = 46;  # интерфейс ksLBreakDimSource       структура параметров привязки лин. размера с обрывом
  ko_BreakDimDrawing       = 47;  # интерфейс ksBreakDimDrawing       структура параметров отрисовки линейного и углового размера с обрывом
  ko_LBreakDimParam        = 48;  # интерфейс ksLBreakDimParam        структура параметров линейного размера с обрывом
  ko_ADimSource            = 49;  # интерфейс ksADimSource            структура параметров привязки углового размера
  ko_ADimParam             = 50;  # интерфейс ksADimParam             структура параметров углового размера
  ko_ABreakDimParam        = 51;  # интерфейс ksABreakDimParam        структура составляющих объектов размера
  ko_RDimSource            = 52;  # интерфейс ksRDimSource            структура параметров привязки диаметрального и радиального размеров
  ko_RDimDrawing           = 53;  # интерфейс ksRDimDrawing           структура параметров отрисовки  диаметрального и радиального размеров
  ko_RDimParam             = 54;  # интерфейс ksRDimParam             сструктура параметров  диаметрального  и  обычного радиального размераCтруктура параметров  диаметрального  и  обычного радиального размера
  ko_RBreakDrawing         = 55;  # интерфейс ksRBreakDrawing         структура параметров отрисовки радиального размера с изломом
  ko_RBreakDimParam        = 56;  # интерфейс ksRBreakDimParam        структура параметров  радиального размера с изломом
  ko_RoughPar              = 57;  # интерфейс ksRoughPar              структура параметров  шероховатости
  ko_ShelfPar              = 58;  # интерфейс ksShelfPar              структура параметров выносной полки шероховатости
  ko_RoughParam            = 59;  # интерфейс ksRoughParam            структура параметров шероховатости
  ko_LeaderParam           = 60;  # интерфейс ksLeaderParam           структура параметров простой линии выноски
  ko_PosLeaderParam        = 61;  # интерфейс ksPosLeaderParam        структура параметров линии выноски для обозначения позиции
  ko_BrandLeaderParam      = 62;  # интерфейс ksBrandLeaderParam      структура параметров линии выноски для обозначения клеймения
  ko_MarkerLeaderParam     = 63;  # интерфейс ksMarkerLeaderParam     структура параметров линии выноски для обозначения маркирования
  ko_BaseParam             = 64;  # интерфейс ksBaseParam             структура базы
  ko_CutLineParam          = 65;  # интерфейс ksCutLineParam          структура параметров линии разреза/сечения
  ko_ViewPointerParam      = 66;  # интерфейс ksViewPointerParam      структура параметров стрелки вида
  ko_ToleranceBranch       = 67;  # интерфейс ksToleranceBranch       структура параметров опоры допуска формы
  ko_ToleranceParam        = 68;  # интерфейс ksToleranceParam        структура параметров одопуска формы
  ko_CurvePattern          = 69;  # интерфейс ksCurvePattern          структура параметров участка штриховой кривой
  ko_CurvePicture          = 70;  # интерфейс ksCurvePicture          структура параметров картинки стиля
  ko_CurvePatternEx        = 71;  # интерфейс ksCurvePatternEx        структура параметров участка штриховой кривой расширенная
  ko_CurveStyleParam       = 72;  # интерфейс ksCurveStyleParam       структура параметров стиля кривой
  ko_DimensionPartsParam   = 73;  # интерфейс ksDimensionPartsParam   структура параметров составляющих объектов размера
  ko_TextStyleParam        = 74;  # интерфейс ksTextStyleParam        структура параметров стиля текста
  ko_ConicArcParam         = 75;  # интерфейс ksConicArcParam         структура параметров конического сечения
  ko_PolylineParam         = 76;  # интерфейс ksPolylineParam         структура параметров полилинии
  ko_LibStyle              = 77;  # интерфейс ksLibStyle              структура параметров для подключения стиля из библиотеки
  ko_TechnicalDemandParam  = 78;  # интерфейс ksTechnicalDemandParam  структура параметров для определения технических требований
  ko_SpecRoughParam        = 79;  # интерфейс ksSpecRoughParam        структура параметров для определения неуказанной шероховатости
  ko_DimensionOptions      = 80;  # интерфейс ksDimensionOptions      структура параметров для определения настроек размеров
  ko_SpcColumnParam        = 81;  # интерфейс ksSpcColumnParam        структура параметров для колонки спецификации
  ko_LibraryStyleParam     = 82;  # интерфейс ksLibraryStyleParam     структура параметров для стиля в библиотеке стилей
  ko_InertiaParam          = 83;  # интерфейс ksInertiaParam          структура параметров для расчета плоских моментно-центровочных характеристик
  ko_MassInertiaParam      = 84;  # интерфейс ksMassInertiaParam      структура параметров для расчета массо-центровочных характеристик
  ko_VariableParam         = 85;  # интерфейс ksVariableParam         структура параметров
  ko_SnapOptions           = 86;  # интерфейс ksSnapOptions           структура параметров привязок в графическом документе
  ko_NurbsParam            = 87;  # интерфейс ksNurbsParam            структура параметров Nurbs-сплайна
  ko_InsertFragmentParam   = 88;  # интерфейс ksInsertFragmentParam   структура параметров вставки фрагмента
  ko_ConstraintParam       = 89;  # интерфейс ksConstraintParam       структура параметров сопряжения
  ko_CornerParam           = 90;  # интерфейс ksCornerParam           структура параметров углов
  ko_RectangleParam        = 91;  # интерфейс ksRectangleParam        структура параметров прямоугольника
  ko_RegularPolygonParam   = 92;  # интерфейс ksRegularPolygonParam   структура параметров многоугольника
  ko_CentreParam           = 93;  # интерфейс ksCentreParam           структура параметров обозначения центра
  ko_DocAttachSpcParam     = 94;  # интерфейс ksDocAttachSpcParam     структура параметров присоединеного документа к объекту спецификации
  ko_SpcObjParam           = 95;  # интерфейс ksSpcObjParam           структура параметров объекта спецификации
  ko_RasterParam           = 96;  # интерфейс ksRasterParam           структура параметров растрового объекта
  ko_RecordTypeAttrParam   = 97;  # интерфейс ksRecordTypeAttrParam   структура параметров для стиля СП заполняется для типа значения RECORD_ATTR_TYPE
  ko_NumberTypeAttrParam   = 98;  # интерфейс ksNumberTypeAttrParam   структура параметров для стиля СП заполняется для типа значения DOUBLE_ATTR_TYPE и LINT_ATTR_TYPE
  ko_SpcStyleColumnParam   = 99;  # интерфейс ksSpcStyleColumnParam   структура параметров колонки таблицы спецификации
  ko_SpcStyleSectionParam  = 100; # интерфейс ksSpcStyleSectionParam  структура параметров стиля разделa спецификации
  ko_SpcSubSectionParam    = 101; # интерфейс ksSpcSubSectionParam    структура параметров подраздела спецификации
  ko_SpcTuningSectionParam = 102; # интерфейс ksSpcTuningSectionParam структура параметров настройки раздела спецификации
  ko_SpcTuningStyleParam   = 103; # интерфейс ksSpcTuningStyleParam   структура параметров стиля настроек спецификации
  ko_SpcStyleParam         = 104; # интерфейс ksSpcStyleParam         структура параметров стиля спецификации
  ko_SpcDescrParam         = 105; # интерфейс ksSpcDescrParam         структура параметров описания спецификации
  ko_QualityItemParam      = 106; # интерфейс ksQualityItemParam      структура параметров записи об одном интервале для какого-то квалитета
  ko_QualityContensParam   = 107; # интерфейс ksQualityContensParam   структура параметров квалитета
  ko_LtVariant             = 108; # интерфейс ksLtVariant             структура параметров варианта
  ko_ContourParam          = 109; # интерфейс ksContourParam          структура параметров контура
  ko_DoubleValue           = 110; # интерфейс ksDoubleValue           структура параметров Nurbs-узела
  ko_Char255               = 111; # интерфейс ksChar255               структура параметров строки
  ko_UserParam             = 112; # интерфейс ksUserParam             пользовательская структура для Get/Set Macroparam и для ReadRecord
  ko_HatchLineParam        = 113; # интерфейс ksHatchLineParam        структура параметров линии штриховки
  ko_HatchStyleParam       = 114; # интерфейс ksHatchStyleParam       структура параметров стиля штриховки
  ko_OrdinatedSourceParam  = 115; # интерфейс ksOrdinatedSourceParam  структура параметров привязки размера высоты
  ko_OrdinatedDrawingParam = 116; # интерфейс ksOrdinatedDrawingParam структура параметров изображения размера высоты
  ko_OrdinatedDimParam     = 117; # интерфейс ksOrdinatedDimParam     структура параметров размера высоты
  ko_SheetOptions          = 118; # интерфейс ksSheetParOptions       структура параметров оформления
  ko_InsertFragmentParamEx = 119; # интерфейс ksInsertFragmentParamEx структура параметров вставки фрагмента
  ko_TreeNodeParam         = 120; # интерфейс ksTreeNodeParam         структура параметров узла дерева
  ko_ViewColorParam        = 121; # интерфейс ksViewColorParam        структура параметров узла дерева
  ko_AssociationViewParam  = 122; # интерфейс ksAssociationViewParam  структура параметров ассоциативного вида
  ko_AxisLineParam         = 123; # интерфейс ksAxisLineParam         структура параметров осевой линии
  ko_TextDocumentParam     = 124; # интерфейс ksTextDocumentParam     структура параметров текстового документа
  ko_RemoteElementParam    = 125; # интерфейс ksRemoteElementParam    структура параметров объекта "Выносной элемент"
  ko_CopyObjectParam       = 126; # интерфейс ksCopyObjectParam       Структура параметров для копирования объекта 2d документа
  ko_OverlapObjectOptions  = 127; # интерфейс ksOverlapObjectOptions  Структура параметров перекрывающихся объектов
  ko_ChangeLeaderParam     = 128; # интерфейс ksChangeLeaderParams    Структура параметров знака изменения
  ko_ParametrisationParam  = 9000; # интерфейс ksParametrisationParam  Структура параметров параметризации группы объектов

def RGB(r,g,b):
    return (b*256+g)*256+r



# -*- coding: mbcs -*-
# Created by makepy.py version 0.5.01
# By python version 3.8.2 (tags/v3.8.2:7b3ab59, Feb 25 2020, 23:03:10) [MSC v.1916 64 bit (AMD64)]
# From type library 'KGAX.tlb'
# On Fri Nov  5 08:14:23 2021
'KGAX ActiveX Control module'
makepy_version = '0.5.01'
python_version = 0x30802f0

import win32com.client.CLSIDToClass, pythoncom, pywintypes
import win32com.client.util
from pywintypes import IID
from win32com.client import Dispatch

# The following 3 lines may need tweaking for the particular server
# Candidates are pythoncom.Missing, .Empty and .ArgNotFound
defaultNamedOptArg=pythoncom.Empty
defaultNamedNotOptArg=pythoncom.Empty
defaultUnnamedArg=pythoncom.Empty

CLSID = IID('{B97871C2-BB9B-49E7-8FD3-C1201922EDD8}')
MajorVersion = 1
MinorVersion = 0
LibraryFlags = 10
LCID = 0x0

class constants:
	vt_HiddenRemovedMode          =1          # from enum KDocument3DDrawMode
	vt_HiddenThinMode             =2          # from enum KDocument3DDrawMode
	vt_ShadedMode                 =3          # from enum KDocument3DDrawMode
	vt_WireframeMode              =0          # from enum KDocument3DDrawMode
	vt_3DAssembly                 =6          # from enum KDocumentType
	vt_3DPart                     =5          # from enum KDocumentType
	vt_Fragment                   =3          # from enum KDocumentType
	vt_SheetStandart              =1          # from enum KDocumentType
	vt_SheetUser                  =2          # from enum KDocumentType
	vt_Spc                        =4          # from enum KDocumentType
	vt_SpcUser                    =9          # from enum KDocumentType
	vt_TechnologyAssemble3D       =10         # from enum KDocumentType
	vt_TextStandart               =7          # from enum KDocumentType
	vt_TextUser                   =8          # from enum KDocumentType
	vt_CurrentLibManager          =1          # from enum KLibManagerMode
	vt_Default                    =0          # from enum KLibManagerMode
	vt_MainLibManager             =-1         # from enum KLibManagerMode
	kTLErrorLoad                  =5          # from enum KTestLoadResultEnum
	kTLErrorLoad217               =217        # from enum KTestLoadResultEnum
	kTLErrorLoad218               =218        # from enum KTestLoadResultEnum
	kTLErrorLoad64                =64         # from enum KTestLoadResultEnum
	kTLIsAppend                   =2          # from enum KTestLoadResultEnum
	kTLIsLoad                     =3          # from enum KTestLoadResultEnum
	kTLIsLoadInKompas             =4          # from enum KTestLoadResultEnum
	kTLNoerror                    =1          # from enum KTestLoadResultEnum
	kTLUnknownError               =0          # from enum KTestLoadResultEnum
	vt_Refresh                    =6          # from enum KZoomType
	vt_ZoomEntureDocument         =5          # from enum KZoomType
	vt_ZoomIn                     =2          # from enum KZoomType
	vt_ZoomOut                    =3          # from enum KZoomType
	vt_ZoomSelected               =4          # from enum KZoomType
	vt_ZoomWindow                 =1          # from enum KZoomType

from win32com.client import DispatchBaseClass
class GLObject(DispatchBaseClass):
	"Вспомогательные данные для event'а OnKgCreateGLList."
	CLSID = IID('{89D7DB83-B61E-4A0A-8317-CE2481FFF4BB}')
	coclass_clsid = None

	def glBegin(self, mode=defaultNamedNotOptArg):
		return self._oleobj_.InvokeTypes(1, LCID, 1, (11, 0), ((3, 1),),mode
			)

	def glColor3d(self, r=defaultNamedNotOptArg, g=defaultNamedNotOptArg, b=defaultNamedNotOptArg):
		return self._oleobj_.InvokeTypes(20, LCID, 1, (11, 0), ((5, 1), (5, 1), (5, 1)),r
			, g, b)

	def glDisable(self, cap=defaultNamedNotOptArg):
		return self._oleobj_.InvokeTypes(4, LCID, 1, (11, 0), ((3, 1),),cap
			)

	def glEnable(self, cap=defaultNamedNotOptArg):
		return self._oleobj_.InvokeTypes(3, LCID, 1, (11, 0), ((3, 1),),cap
			)

	def glEnd(self):
		return self._oleobj_.InvokeTypes(2, LCID, 1, (11, 0), (),)

	def glLineStipple(self, factor=defaultNamedNotOptArg, pattern=defaultNamedNotOptArg):
		return self._oleobj_.InvokeTypes(22, LCID, 1, (11, 0), ((3, 1), (2, 1)),factor
			, pattern)

	def glLineWidth(self, w=defaultNamedNotOptArg):
		return self._oleobj_.InvokeTypes(21, LCID, 1, (11, 0), ((5, 1),),w
			)

	def glPointSize(self, w=defaultNamedNotOptArg):
		return self._oleobj_.InvokeTypes(23, LCID, 1, (11, 0), ((5, 1),),w
			)

	def glPolygonMode(self, face=defaultNamedNotOptArg, mode=defaultNamedNotOptArg):
		return self._oleobj_.InvokeTypes(24, LCID, 1, (11, 0), ((3, 1), (3, 1)),face
			, mode)

	def glVertex2d(self, x=defaultNamedNotOptArg, y=defaultNamedNotOptArg):
		return self._oleobj_.InvokeTypes(40, LCID, 1, (11, 0), ((5, 1), (5, 1)),x
			, y)

	def glVertex2dv(self, pData=defaultNamedNotOptArg, countDouble=defaultNamedNotOptArg):
		return self._oleobj_.InvokeTypes(41, LCID, 1, (11, 0), ((16389, 1), (3, 1)),pData
			, countDouble)

	def glVertex3d(self, x=defaultNamedNotOptArg, y=defaultNamedNotOptArg, z=defaultNamedNotOptArg):
		return self._oleobj_.InvokeTypes(42, LCID, 1, (11, 0), ((5, 1), (5, 1), (5, 1)),x
			, y, z)

	def glVertex3dv(self, pData=defaultNamedNotOptArg, countDouble=defaultNamedNotOptArg):
		return self._oleobj_.InvokeTypes(43, LCID, 1, (11, 0), ((16389, 1), (3, 1)),pData
			, countDouble)

	def glVertex4d(self, x=defaultNamedNotOptArg, y=defaultNamedNotOptArg, z=defaultNamedNotOptArg, w=defaultNamedNotOptArg):
		return self._oleobj_.InvokeTypes(44, LCID, 1, (11, 0), ((5, 1), (5, 1), (5, 1), (5, 1)),x
			, y, z, w)

	def glVertex4dv(self, pData=defaultNamedNotOptArg, countDouble=defaultNamedNotOptArg):
		return self._oleobj_.InvokeTypes(45, LCID, 1, (11, 0), ((16389, 1), (3, 1)),pData
			, countDouble)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class GabaritObject(DispatchBaseClass):
	"Вспомогательные данные для event'а OnKgAddGabatit."
	CLSID = IID('{89D7DB83-B61E-4A0A-8317-CE2481FFF4BC}')
	coclass_clsid = None

	def AddGabarit(self, p1X=defaultNamedNotOptArg, p1Y=defaultNamedNotOptArg, p1Z=defaultNamedNotOptArg, p2X=defaultNamedNotOptArg
			, p2Y=defaultNamedNotOptArg, p2Z=defaultNamedNotOptArg):
		'Добавить дополнительный габарит к габариту документа.'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (11, 0), ((5, 1), (5, 1), (5, 1), (5, 1), (5, 1), (5, 1)),p1X
			, p1Y, p1Z, p2X, p2Y, p2Z
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class PaintObject(DispatchBaseClass):
	"Вспомогательные данные для event'а OnKgPaint."
	CLSID = IID('{89D7DB83-B61E-4A0A-8317-CE2481FFF4BA}')
	coclass_clsid = None

	def GetDC(self):
		'Получить Handle контекста отображения.'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (3, 0), (),)

	def GetHWND(self):
		'Получить Handle окна.'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def GetTransformMatrix(self, a11=pythoncom.Missing, a12=pythoncom.Missing, a13=pythoncom.Missing, a14=pythoncom.Missing
			, a21=pythoncom.Missing, a22=pythoncom.Missing, a23=pythoncom.Missing, a24=pythoncom.Missing):
		'Получить коэффициенты для матрицы преобразования координат.'
		return self._ApplyTypes_(4, 1, (11, 0), ((16389, 2), (16389, 2), (16389, 2), (16389, 2), (16389, 2), (16389, 2), (16389, 2), (16389, 2)), 'GetTransformMatrix', None,a11
			, a12, a13, a14, a21, a22
			, a23, a24)

	def ReleaseDC(self, dc=defaultNamedNotOptArg):
		'Закрыть Handle контекста отображения.'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (11, 0), ((3, 1),),dc
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class _DKGAX(DispatchBaseClass):
	'Dispatch interface for KGAX Control'
	CLSID = IID('{92B3A942-4E70-463B-9462-6424D9CE40CB}')
	coclass_clsid = IID('{6B943E71-5CA2-435D-AFA3-D7817B13ACA2}')

	def ActivateDocument(self, index=defaultNamedNotOptArg):
		'Активизирует документ по имени, идентификатору или индексу или reference.'
		return self._oleobj_.InvokeTypes(15, LCID, 1, (11, 0), ((12, 1),),index
			)

	def AddDocument(self, fileName=defaultNamedNotOptArg):
		'Добавить документ. Возвращает уникальный идентификатор документа.'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (3, 0), ((8, 1),),fileName
			)

	def AddNewDocument(self, type=defaultNamedNotOptArg):
		'Добавить документ. Возвращает уникальный идентификатор документа.'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (3, 0), ((3, 1),),type
			)

	def CloseAll(self):
		'Закрыть все документы.'
		return self._oleobj_.InvokeTypes(16, LCID, 1, (3, 0), (),)

	def DrawToDC(self, dc=defaultNamedNotOptArg, left=defaultNamedNotOptArg, top=defaultNamedNotOptArg, width=defaultNamedNotOptArg
			, height=defaultNamedNotOptArg):
		'Отрисовать документ на заданном HDC.'
		return self._oleobj_.InvokeTypes(26, LCID, 1, (11, 0), ((3, 1), (3, 1), (3, 1), (3, 1), (3, 1)),dc
			, left, top, width, height)

	def GetActiveDocumentID(self):
		'Получает идентификатор активного документа.'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def GetDocumentID(self, index=defaultNamedNotOptArg):
		'Получить идентификатор документа по индексу. -1 - активный.'
		return self._oleobj_.InvokeTypes(29, LCID, 1, (3, 0), ((12, 1),),index
			)

	def GetDocumentInterface(self, index=defaultNamedNotOptArg, newAPI=defaultNamedNotOptArg):
		'Получить указатель на документ по индексу. -1 - активный.'
		ret = self._oleobj_.InvokeTypes(7, LCID, 1, (9, 0), ((12, 1), (3, 0)),index
			, newAPI)
		if ret is not None:
			ret = Dispatch(ret, 'GetDocumentInterface', None)
		return ret

	def GetDocumentType(self, index=defaultNamedNotOptArg):
		'Получить тип документа по индексу. -1 - активный.'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (3, 0), ((12, 1),),index
			)

	def GetDocumentsCount(self):
		'Получить количество открытых в KGAX документов.'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	# Result is of type KompasObject
	def GetKompasObject(self):
		'Получить интерфейс на API КОМПАС-3D.'
		ret = self._oleobj_.InvokeTypes(5, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, 'GetKompasObject', '{E36BC97C-39D6-4402-9C25-C7008A217E02}')
		return ret

	def InsertDocument(self, fileName=defaultNamedNotOptArg, index=defaultNamedNotOptArg):
		'Открыть документ с заданным именем и индексом в KGAX.'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (3, 0), ((8, 1), (12, 1)),fileName
			, index)

	def InsertNewDocument(self, type=defaultNamedNotOptArg, index=defaultNamedNotOptArg):
		'Открыть документ с заданным именем и индексом в KGAX.'
		return self._oleobj_.InvokeTypes(13, LCID, 1, (3, 0), ((3, 1), (12, 1)),type
			, index)

	def InvalidateActiveDocument(self, erase=defaultNamedNotOptArg):
		'Перерисовать окно активного документа.'
		return self._oleobj_.InvokeTypes(18, LCID, 1, (11, 0), ((11, 1),),erase
			)

	def MoveViewDocument(self):
		'Сдвинуть изображение.'
		return self._oleobj_.InvokeTypes(20, LCID, 1, (24, 0), (),)

	def OrientationDocument(self):
		'Ориентация изображения.'
		return self._oleobj_.InvokeTypes(23, LCID, 1, (24, 0), (),)

	def PanoramaViewDocument(self):
		'Приблизить/отдалить изображение.'
		return self._oleobj_.InvokeTypes(21, LCID, 1, (24, 0), (),)

	def RemoveDocument(self, index=defaultNamedNotOptArg):
		'Закрыть документ по имени, идентификатору или индексу. -1 - активный.'
		return self._oleobj_.InvokeTypes(14, LCID, 1, (11, 0), ((12, 1),),index
			)

	def RotateViewDocument(self):
		'Повернуть изображение.'
		return self._oleobj_.InvokeTypes(22, LCID, 1, (24, 0), (),)

	def SetCurrentLibManager(self, t=defaultNamedNotOptArg):
		'Установить текущий менеджер библиотек.'
		return self._oleobj_.InvokeTypes(27, LCID, 1, (24, 0), ((3, 1),),t
			)

	def SetGabaritModifying(self):
		'Взвести флаг изменения габарита документа для собственного рисования в окне.'
		return self._oleobj_.InvokeTypes(28, LCID, 1, (24, 0), (),)

	def StopCurrentProcess(self, cancel=False):
		'Завершить текущий процесс.'
		return self._oleobj_.InvokeTypes(25, LCID, 1, (24, 0), ((11, 49),),cancel
			)

	def TestLoadDocument(self, fileName=defaultNamedNotOptArg):
		'Проверить возможность добавления докумета в KGAX.'
		return self._oleobj_.InvokeTypes(17, LCID, 1, (3, 0), ((8, 1),),fileName
			)

	def ZoomEntireDocument(self):
		'Показать в окне весь документ.'
		return self._oleobj_.InvokeTypes(19, LCID, 1, (24, 0), (),)

	def ZoomWindow(self, type=1):
		'Macштабировать окно документа.'
		return self._oleobj_.InvokeTypes(24, LCID, 1, (24, 0), ((3, 49),),type
			)

	_prop_map_get_ = {
		"Caption": (-518, 2, (8, 0), (), "Caption", None),
		"DocumenFileName": (2, 2, (8, 0), (), "DocumenFileName", None),
		"Document3DDrawMode": (3, 2, (3, 0), (), "Document3DDrawMode", None),
		"Document3DWireframeShadedMode": (4, 2, (11, 0), (), "Document3DWireframeShadedMode", None),
		"DocumentType": (1, 2, (3, 0), (), "DocumentType", None),
		"Text": (-517, 2, (8, 0), (), "Text", None),
	}
	_prop_map_put_ = {
		"Caption" : ((-518, LCID, 4, 0),()),
		"DocumenFileName" : ((2, LCID, 4, 0),()),
		"Document3DDrawMode" : ((3, LCID, 4, 0),()),
		"Document3DWireframeShadedMode" : ((4, LCID, 4, 0),()),
		"DocumentType" : ((1, LCID, 4, 0),()),
		"Text" : ((-517, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class _DKGAXEvents:
	'Event interface for KGAX Control'
	CLSID = CLSID_Sink = IID('{464F746A-AC6D-4919-82E9-A7363E661ECF}')
	coclass_clsid = IID('{6B943E71-5CA2-435D-AFA3-D7817B13ACA2}')
	_public_methods_ = [] # For COM Server support
	_dispid_to_func_ = {
		        1 : "OnKgMouseDown",
		        2 : "OnKgMouseUp",
		        3 : "OnKgMouseDblClick",
		        4 : "OnKgStopCurrentProcess",
		        5 : "OnKgCreate",
		        6 : "OnKgPaint",
		        7 : "OnKgCreateGLList",
		        8 : "OnKgAddGabatit",
		        9 : "OnKgErrorLoadDocument",
		       10 : "OnKgKeyDown",
		       11 : "OnKgKeyUp",
		       12 : "OnKgKeyPress",
		}

	def __init__(self, oobj = None):
		if oobj is None:
			self._olecp = None
		else:
			import win32com.server.util
			from win32com.server.policy import EventHandlerPolicy
			cpc=oobj._oleobj_.QueryInterface(pythoncom.IID_IConnectionPointContainer)
			cp=cpc.FindConnectionPoint(self.CLSID_Sink)
			cookie=cp.Advise(win32com.server.util.wrap(self, usePolicy=EventHandlerPolicy))
			self._olecp,self._olecp_cookie = cp,cookie
	def __del__(self):
		try:
			self.close()
		except pythoncom.com_error:
			pass
	def close(self):
		if self._olecp is not None:
			cp,cookie,self._olecp,self._olecp_cookie = self._olecp,self._olecp_cookie,None,None
			cp.Unadvise(cookie)
	def _query_interface_(self, iid):
		import win32com.server.util
		if iid==self.CLSID_Sink: return win32com.server.util.wrap(self)

	# Event Handlers
	# If you create handlers, they should have the following prototypes:
#	def OnKgMouseDown(self, nButton=defaultNamedNotOptArg, nShiftState=defaultNamedNotOptArg, x=defaultNamedNotOptArg, y=defaultNamedNotOptArg
#			, proceed=pythoncom.Missing):
#		'Нажатие кнопки мыши.'
#	def OnKgMouseUp(self, nButton=defaultNamedNotOptArg, nShiftState=defaultNamedNotOptArg, x=defaultNamedNotOptArg, y=defaultNamedNotOptArg
#			, proceed=pythoncom.Missing):
#		'Отпускание кнопки мыши.'
#	def OnKgMouseDblClick(self, nButton=defaultNamedNotOptArg, nShiftState=defaultNamedNotOptArg, x=defaultNamedNotOptArg, y=defaultNamedNotOptArg
#			, proceed=pythoncom.Missing):
#		'Двойной клик кнопки мыши.'
#	def OnKgStopCurrentProcess(self):
#		'Окончание процесса панаромирования, поворота, сдвига и т.д.'
#	def OnKgCreate(self, docID=defaultNamedNotOptArg):
#		'Окончание создания окна.'
#	def OnKgPaint(self, paintObj=defaultNamedNotOptArg):
#		'Окончание отрисовки в окне.'
#	def OnKgCreateGLList(self, glObj=defaultNamedNotOptArg, drawMode=defaultNamedNotOptArg):
#		'Окончание создания листа в контекста OpenGL.'
#	def OnKgAddGabatit(self, gabObj=defaultNamedNotOptArg):
#		'Определение габаритов документа.'
#	def OnKgErrorLoadDocument(self, docID=defaultNamedNotOptArg, fileName=defaultNamedNotOptArg, errorID=defaultNamedNotOptArg):
#		'Событие ошибки загрузки документа.'
#	def OnKgKeyDown(self, key=defaultNamedNotOptArg, nShiftState=defaultNamedNotOptArg):
#		'Событие нажатия клавиатуры когда контрол находится в фокусе.'
#	def OnKgKeyUp(self, key=defaultNamedNotOptArg, nShiftState=defaultNamedNotOptArg):
#		'Событие нажатия клавиатуры когда контрол находится в фокусе.'
#	def OnKgKeyPress(self, key=defaultNamedNotOptArg):
#		'Событие нажатия клавиатуры когда контрол находится в фокусе.'


from win32com.client import CoClassBaseClass
# This CoClass is known by the name 'KGAX.KGAXCtrl.1'
class KGAX(CoClassBaseClass): # A CoClass
	# KGAX Control
	CLSID = IID('{6B943E71-5CA2-435D-AFA3-D7817B13ACA2}')
	coclass_sources = [
		_DKGAXEvents,
	]
	default_source = _DKGAXEvents
	coclass_interfaces = [
		_DKGAX,
	]
	default_interface = _DKGAX

RecordMap = {
}

CLSIDToClassMap = {
	'{89D7DB83-B61E-4A0A-8317-CE2481FFF4BA}' : PaintObject,
	'{89D7DB83-B61E-4A0A-8317-CE2481FFF4BB}' : GLObject,
	'{89D7DB83-B61E-4A0A-8317-CE2481FFF4BC}' : GabaritObject,
	'{92B3A942-4E70-463B-9462-6424D9CE40CB}' : _DKGAX,
	'{464F746A-AC6D-4919-82E9-A7363E661ECF}' : _DKGAXEvents,
	'{6B943E71-5CA2-435D-AFA3-D7817B13ACA2}' : KGAX,
}
CLSIDToPackageMap = {}
win32com.client.CLSIDToClass.RegisterCLSIDsFromDict( CLSIDToClassMap )
VTablesToPackageMap = {}
VTablesToClassMap = {
}


NamesToIIDMap = {
	'PaintObject' : '{89D7DB83-B61E-4A0A-8317-CE2481FFF4BA}',
	'GLObject' : '{89D7DB83-B61E-4A0A-8317-CE2481FFF4BB}',
	'GabaritObject' : '{89D7DB83-B61E-4A0A-8317-CE2481FFF4BC}',
	'_DKGAX' : '{92B3A942-4E70-463B-9462-6424D9CE40CB}',
	'_DKGAXEvents' : '{464F746A-AC6D-4919-82E9-A7363E661ECF}',
}

win32com.client.constants.__dicts__.append(constants.__dict__)

